@@ -704,6 +704,8 @@ _WBWombat = (function() {
                     override_attr(created, "src");
                 } else if (created.tagName == "IMG") {
                     override_attr(created, "src");
+                } else if (created.tagName == "EMBED") {
+                    console.log("EMBED ADDED");
                 }
 //                } else if (created.tagName == "A") {
 //                    override_attr(created, "href");
@@ -712,6 +714,7 @@ _WBWombat = (function() {
                 var custom_h = _tag_handlers[created.tagName];
 
                 if (custom_h) {
+                    console.log("HANDLERS FOR: " + created.tagName);
                     for (var i = 0; i < custom_h.length; i++) {
                         custom_h.call(created);
                     }
